.. _usage:

=====
Usage
=====

cihai is designed to work out-of-the-box without configuration.

Installation
------------

.. code-block:: sh

   $ pip install --user cihai[cli]

Configuration
-------------

See :ref:`cihai's configuration <cihai:configuration>` documentation.
